import React from 'react';
import './dashboard.css';

const LicenseDistributionPage = () => {
  // Sample data
  const licenseStats = [
    { label: 'Active Licenses', value: '1,245', change: '+5%' },
    { label: 'Expired Licenses', value: '89', change: '-2%' },
    { label: 'Pending Activations', value: '32', change: '+12%' },
    { label: 'Total Revenue', value: '$48,750', change: '+8%' },
  ];

  const recentDistributions = [
    { id: 'LIC-1001', product: 'Business Suite', distributor: 'TechDistro', date: '2023-05-15', status: 'Active' },
    { id: 'LIC-1002', product: 'Security Pro', distributor: 'SoftLink', date: '2023-05-14', status: 'Pending' },
    { id: 'LIC-1003', product: 'Design Master', distributor: 'DigitalOne', date: '2023-05-12', status: 'Active' },
    { id: 'LIC-1004', product: 'Business Suite', distributor: 'TechDistro', date: '2023-05-10', status: 'Expired' },
  ];

  return (
    <div className="dashboard-container">
      <h2 className="dashboard-header">License Distribution Management</h2>
      
      <div className="stats-grid">
        {licenseStats.map((stat, index) => (
          <div key={index} className="stat-card">
            <div className="stat-value">{stat.value}</div>
            <div className="stat-label">{stat.label}</div>
            <small style={{ color: stat.change.startsWith('+') ? '#27ae60' : '#e74c3c' }}>
              {stat.change} from last month
            </small>
          </div>
        ))}
      </div>
      
      <div className="dashboard-card">
        <h3 className="card-title">Recent License Distributions</h3>
        <div className="search-filter">
          <input type="text" className="search-box" placeholder="Search licenses..." />
          <select className="filter-select">
            <option>All Status</option>
            <option>Active</option>
            <option>Pending</option>
            <option>Expired</option>
          </select>
        </div>
        <div className="table-container">
          <table className="data-table">
            <thead>
              <tr>
                <th>License ID</th>
                <th>Product</th>
                <th>Distributor</th>
                <th>Date</th>
                <th>Status</th>
                <th>Actions</th>
              </tr>
            </thead>
            <tbody>
              {recentDistributions.map((license, index) => (
                <tr key={index}>
                  <td>{license.id}</td>
                  <td>{license.product}</td>
                  <td>{license.distributor}</td>
                  <td>{license.date}</td>
                  <td>
                    <span style={{
                      padding: '4px 8px',
                      borderRadius: '12px',
                      backgroundColor: 
                        license.status === 'Active' ? '#d5f5e3' :
                        license.status === 'Pending' ? '#fef9e7' : '#fadbd8',
                      color: 
                        license.status === 'Active' ? '#27ae60' :
                        license.status === 'Pending' ? '#f39c12' : '#e74c3c'
                    }}>
                      {license.status}
                    </span>
                  </td>
                  <td>
                    <button className="action-btn">View</button>
                    <button className="action-btn secondary">Edit</button>
                  </td>
                </tr>
              ))}
            </tbody>
          </table>
        </div>
      </div>
      
      <div className="dashboard-card">
        <h3 className="card-title">License Distribution Analytics</h3>
        <div className="chart-container">
          {/* This would be replaced with an actual chart component */}
          <div style={{
            background: '#f8f9fa',
            height: '100%',
            display: 'flex',
            alignItems: 'center',
            justifyContent: 'center',
            color: '#7f8c8d'
          }}>
            [License Distribution Chart - Monthly Trends]
          </div>
        </div>
      </div>
    </div>
  );
};

export default LicenseDistributionPage;