import React from 'react';
import './dashboard.css';
const OrderManagementPage = () => {
  const orderStats = [
    { label: 'Total Orders', value: '328', change: '+15%' },
    { label: 'Pending Orders', value: '24', change: '-3%' },
    { label: 'Completed Orders', value: '289', change: '+18%' },
    { label: 'Avg. Processing Time', value: '2.4 days', change: '-0.5' },
  ];

  const recentOrders = [
    { id: 'ORD-2023-1056', customer: 'ABC Corp', product: 'Business Suite', amount: '$1,200', date: '2023-05-15', status: 'Processing' },
    { id: 'ORD-2023-1055', customer: 'XYZ Ltd', product: 'Security Pro', amount: '$850', date: '2023-05-14', status: 'Shipped' },
    { id: 'ORD-2023-1054', customer: 'Acme Inc', product: 'Design Master', amount: '$650', date: '2023-05-13', status: 'Completed' },
    { id: 'ORD-2023-1053', customer: 'Global Tech', product: 'Business Suite', amount: '$2,400', date: '2023-05-12', status: 'Completed' },
  ];

  return (
    <div className="dashboard-container">
      <h2 className="dashboard-header">Order Management System</h2>
      
      <div className="stats-grid">
        {orderStats.map((stat, index) => (
          <div key={index} className="stat-card">
            <div className="stat-value">{stat.value}</div>
            <div className="stat-label">{stat.label}</div>
            <small style={{ color: stat.change.startsWith('+') ? '#27ae60' : stat.change.startsWith('-') ? '#e74c3c' : '#3498db' }}>
              {stat.change.startsWith('-') ? stat.change : `+${stat.change}`} from last month
            </small>
          </div>
        ))}
      </div>
      
      <div className="dashboard-card">
        <h3 className="card-title">Recent Orders</h3>
        <div className="search-filter">
          <input type="text" className="search-box" placeholder="Search orders..." />
          <select className="filter-select">
            <option>All Status</option>
            <option>Processing</option>
            <option>Shipped</option>
            <option>Completed</option>
            <option>Cancelled</option>
          </select>
        </div>
        <div className="table-container">
          <table className="data-table">
            <thead>
              <tr>
                <th>Order ID</th>
                <th>Customer</th>
                <th>Product</th>
                <th>Amount</th>
                <th>Date</th>
                <th>Status</th>
                <th>Actions</th>
              </tr>
            </thead>
            <tbody>
              {recentOrders.map((order, index) => (
                <tr key={index}>
                  <td>{order.id}</td>
                  <td>{order.customer}</td>
                  <td>{order.product}</td>
                  <td>{order.amount}</td>
                  <td>{order.date}</td>
                  <td>
                    <span style={{
                      padding: '4px 8px',
                      borderRadius: '12px',
                      backgroundColor: 
                        order.status === 'Completed' ? '#d5f5e3' :
                        order.status === 'Processing' ? '#fef9e7' : 
                        order.status === 'Shipped' ? '#d6eaf8' : '#fadbd8',
                      color: 
                        order.status === 'Completed' ? '#27ae60' :
                        order.status === 'Processing' ? '#f39c12' : 
                        order.status === 'Shipped' ? '#3498db' : '#e74c3c'
                    }}>
                      {order.status}
                    </span>
                  </td>
                  <td>
                    <button className="action-btn">Details</button>
                    <button className="action-btn secondary">Track</button>
                    {order.status === 'Processing' && (
                      <button className="action-btn danger">Cancel</button>
                    )}
                  </td>
                </tr>
              ))}
            </tbody>
          </table>
        </div>
      </div>
      
      <div className="dashboard-card">
        <h3 className="card-title">Order Fulfillment Workflow</h3>
        <div style={{ display: 'flex', justifyContent: 'space-between', marginTop: '20px' }}>
          <div style={{ textAlign: 'center', flex: 1 }}>
            <div style={{ 
              width: '60px',
              height: '60px',
              borderRadius: '50%',
              backgroundColor: '#3498db',
              color: 'white',
              display: 'flex',
              alignItems: 'center',
              justifyContent: 'center',
              margin: '0 auto 10px',
              fontSize: '24px'
            }}>1</div>
            <h4>Order Received</h4>
            <p style={{ color: '#7f8c8d' }}>Customer places order</p>
          </div>
          <div style={{ textAlign: 'center', flex: 1 }}>
            <div style={{ 
              width: '60px',
              height: '60px',
              borderRadius: '50%',
              backgroundColor: '#3498db',
              color: 'white',
              display: 'flex',
              alignItems: 'center',
              justifyContent: 'center',
              margin: '0 auto 10px',
              fontSize: '24px'
            }}>2</div>
            <h4>Processing</h4>
            <p style={{ color: '#7f8c8d' }}>Verification & preparation</p>
          </div>
          <div style={{ textAlign: 'center', flex: 1 }}>
            <div style={{ 
              width: '60px',
              height: '60px',
              borderRadius: '50%',
              backgroundColor: '#3498db',
              color: 'white',
              display: 'flex',
              alignItems: 'center',
              justifyContent: 'center',
              margin: '0 auto 10px',
              fontSize: '24px'
            }}>3</div>
            <h4>License Generation</h4>
            <p style={{ color: '#7f8c8d' }}>Create & validate license</p>
          </div>
          <div style={{ textAlign: 'center', flex: 1 }}>
            <div style={{ 
              width: '60px',
              height: '60px',
              borderRadius: '50%',
              backgroundColor: '#3498db',
              color: 'white',
              display: 'flex',
              alignItems: 'center',
              justifyContent: 'center',
              margin: '0 auto 10px',
              fontSize: '24px'
            }}>4</div>
            <h4>Delivery</h4>
            <p style={{ color: '#7f8c8d' }}>Send to customer</p>
          </div>
        </div>
      </div>
    </div>
  );
};

export default OrderManagementPage;