import React from 'react';
import './dashboard.css';
const PaymentBillingPage = () => {
  const paymentStats = [
    { label: 'Total Revenue', value: '$86,450', change: '+12%' },
    { label: 'Pending Payments', value: '$5,720', change: '-3%' },
    { label: 'Avg. Payment Time', value: '2.1 days', change: '-0.3' },
    { label: 'Successful Transactions', value: '94.7%', change: '+1.2%' },
  ];

  const recentTransactions = [
    { id: 'TXN-58741', invoice: 'INV-2023-1056', amount: '$1,200', date: '2023-05-15', method: 'Credit Card', status: 'Completed' },
    { id: 'TXN-58740', invoice: 'INV-2023-1055', amount: '$850', date: '2023-05-14', method: 'PayPal', status: 'Completed' },
    { id: 'TXN-58739', invoice: 'INV-2023-1054', amount: '$650', date: '2023-05-13', method: 'Bank Transfer', status: 'Pending' },
    { id: 'TXN-58738', invoice: 'INV-2023-1053', amount: '$2,400', date: '2023-05-12', method: 'Credit Card', status: 'Failed' },
  ];

  const upcomingInvoices = [
    { invoice: 'INV-2023-1057', client: 'ABC Corp', amount: '$1,500', dueDate: '2023-05-20', status: 'Unpaid' },
    { invoice: 'INV-2023-1058', client: 'XYZ Ltd', amount: '$950', dueDate: '2023-05-21', status: 'Unpaid' },
    { invoice: 'INV-2023-1059', client: 'Acme Inc', amount: '$2,100', dueDate: '2023-05-22', status: 'Unpaid' },
  ];

  return (
    <div className="dashboard-container">
      <h2 className="dashboard-header">Payment & Billing Management</h2>
      
      <div className="stats-grid">
        {paymentStats.map((stat, index) => (
          <div key={index} className="stat-card">
            <div className="stat-value">{stat.value}</div>
            <div className="stat-label">{stat.label}</div>
            <small style={{ color: stat.change.startsWith('+') ? '#27ae60' : stat.change.startsWith('-') ? '#e74c3c' : '#3498db' }}>
              {stat.change.startsWith('-') ? stat.change : `+${stat.change}`} from last month
            </small>
          </div>
        ))}
      </div>
      
      <div className="dashboard-card">
        <h3 className="card-title">Recent Transactions</h3>
        <div className="search-filter">
          <input type="text" className="search-box" placeholder="Search transactions..." />
          <select className="filter-select">
            <option>All Status</option>
            <option>Completed</option>
            <option>Pending</option>
            <option>Failed</option>
          </select>
        </div>
        <div className="table-container">
          <table className="data-table">
            <thead>
              <tr>
                <th>Transaction ID</th>
                <th>Invoice</th>
                <th>Amount</th>
                <th>Date</th>
                <th>Method</th>
                <th>Status</th>
                <th>Actions</th>
              </tr>
            </thead>
            <tbody>
              {recentTransactions.map((txn, index) => (
                <tr key={index}>
                  <td>{txn.id}</td>
                  <td>{txn.invoice}</td>
                  <td>{txn.amount}</td>
                  <td>{txn.date}</td>
                  <td>{txn.method}</td>
                  <td>
                    <span style={{
                      padding: '4px 8px',
                      borderRadius: '12px',
                      backgroundColor: 
                        txn.status === 'Completed' ? '#d5f5e3' :
                        txn.status === 'Pending' ? '#fef9e7' : '#fadbd8',
                      color: 
                        txn.status === 'Completed' ? '#27ae60' :
                        txn.status === 'Pending' ? '#f39c12' : '#e74c3c'
                    }}>
                      {txn.status}
                    </span>
                  </td>
                  <td>
                    <button className="action-btn">Details</button>
                    {txn.status === 'Pending' && (
                      <button className="action-btn secondary">Remind</button>
                    )}
                    {txn.status === 'Failed' && (
                      <button className="action-btn danger">Retry</button>
                    )}
                  </td>
                </tr>
              ))}
            </tbody>
          </table>
        </div>
      </div>
      
      <div className="dashboard-card">
        <h3 className="card-title">Upcoming Invoices</h3>
        <div className="table-container">
          <table className="data-table">
            <thead>
              <tr>
                <th>Invoice</th>
                <th>Client</th>
                <th>Amount</th>
                <th>Due Date</th>
                <th>Status</th>
                <th>Actions</th>
              </tr>
            </thead>
            <tbody>
              {upcomingInvoices.map((invoice, index) => (
                <tr key={index}>
                  <td>{invoice.invoice}</td>
                  <td>{invoice.client}</td>
                  <td>{invoice.amount}</td>
                  <td>{invoice.dueDate}</td>
                  <td>
                    <span style={{
                      padding: '4px 8px',
                      borderRadius: '12px',
                      backgroundColor: '#fef9e7',
                      color: '#f39c12'
                    }}>
                      {invoice.status}
                    </span>
                  </td>
                  <td>
                    <button className="action-btn">View</button>
                    <button className="action-btn secondary">Send Reminder</button>
                  </td>
                </tr>
              ))}
            </tbody>
          </table>
        </div>
      </div>
      
      <div className="dashboard-card">
        <h3 className="card-title">Revenue Analytics</h3>
        <div className="chart-container">
          {/* This would be replaced with an actual chart component */}
          <div style={{
            background: '#f8f9fa',
            height: '100%',
            display: 'flex',
            alignItems: 'center',
            justifyContent: 'center',
            color: '#7f8c8d'
          }}>
            [Revenue Chart - Monthly Trends by Payment Method]
          </div>
        </div>
      </div>
    </div>
  );
};

export default PaymentBillingPage;