// SalesPerformancePage.jsx
import React from 'react';
import { Line } from 'react-chartjs-2';
import { Chart as ChartJS } from 'chart.js/auto';

const SalesPerformancePage = () => {
  const salesData = {
    labels: ['Ocak', 'Şubat', 'Mart', 'Nisan', 'Mayıs', 'Haziran'],
    datasets: [
      {
        label: 'Aylık Satışlar (TL)',
        data: [65000, 59000, 80000, 81000, 56000, 95000],
        borderColor: '#4A90E2',
        tension: 0.4,
      },
    ],
  };

  const regionalSales = {
    'İstanbul': 45,
    'Ankara': 25,
    'İzmir': 15,
    'Diğer': 15
  };

  return (
    <div className="dashboard-page">
      <h2 className="page-title">Satış Performansı</h2>
      
      <div className="grid-container">
        <div className="chart-card">
          <h3>Aylık Satış Trendi</h3>
          <Line data={salesData} />
        </div>

        <div className="metrics-card">
          <h3>Bölgesel Dağılım</h3>
          <div className="regional-distribution">
            {Object.entries(regionalSales).map(([region, percent]) => (
              <div key={region} className="region-item">
                <div className="region-label">
                  <span>{region}</span>
                  <span>{percent}%</span>
                </div>
                <div className="progress-bar">
                  <div 
                    className="progress-fill" 
                    style={{ width: `${percent}%` }}
                  ></div>
                </div>
              </div>
            ))}
          </div>
        </div>

        <div className="recent-sales">
          <h3>Son İşlemler</h3>
          <table>
            <thead>
              <tr>
                <th>Tarih</th>
                <th>Ürün</th>
                <th>Miktar</th>
                <th>Durum</th>
              </tr>
            </thead>
            <tbody>
              {[...Array(5)].map((_, i) => (
                <tr key={i}>
                  <td>2023-0{i+1}-15</td>
                  <td>Yazılım Paketi {i+1}</td>
                  <td>{(i+1)*1450} TL</td>
                  <td><span className="status completed">Tamamlandı</span></td>
                </tr>
              ))}
            </tbody>
          </table>
        </div>
      </div>
    </div>
  );
};

export default SalesPerformancePage;