// SalesReportsPage.jsx
import React, { useState } from 'react';

const SalesReportsPage = () => {
  const [filters, setFilters] = useState({
    dateRange: 'month',
    productCategory: 'all',
    region: 'all'
  });

  const reports = [...Array(8)].map((_, i) => ({
    id: i+1,
    date: `2023-Q${Math.floor(i/2)+1}`,
    product: `Ürün Kategorisi ${i%3+1}`,
    region: ['İstanbul', 'Ankara', 'İzmir'][i%3],
    total: (i+1)*17500,
    status: ['pending', 'completed'][i%2]
  }));

  return (
    <div className="dashboard-page">
      <h2 className="page-title">Satış Raporları</h2>
      
      <div className="report-filters">
        <select 
          value={filters.dateRange}
          onChange={(e) => setFilters({...filters, dateRange: e.target.value})}
        >
          <option value="week">Son 1 Hafta</option>
          <option value="month">Son 1 Ay</option>
          <option value="quarter">Son 3 Ay</option>
        </select>

        <select
          value={filters.productCategory}
          onChange={(e) => setFilters({...filters, productCategory: e.target.value})}
        >
          <option value="all">Tüm Kategoriler</option>
          <option value="1">ERP Çözümleri</option>
          <option value="2">Bulut Hizmetleri</option>
        </select>

        <select
          value={filters.region}
          onChange={(e) => setFilters({...filters, region: e.target.value})}
        >
          <option value="all">Tüm Bölgeler</option>
          <option value="istanbul">İstanbul</option>
          <option value="ankara">Ankara</option>
        </select>
      </div>

      <div className="report-table">
        <table>
          <thead>
            <tr>
              <th>Çeyrek</th>
              <th>Ürün Kategorisi</th>
              <th>Bölge</th>
              <th>Toplam Satış</th>
              <th>Durum</th>
              <th>İşlemler</th>
            </tr>
          </thead>
          <tbody>
            {reports.map(report => (
              <tr key={report.id}>
                <td>{report.date}</td>
                <td>{report.product}</td>
                <td>{report.region}</td>
                <td>{report.total.toLocaleString()} TL</td>
                <td>
                  <span className={`status ${report.status}`}>
                    {report.status === 'completed' ? 'Tamamlandı' : 'Beklemede'}
                  </span>
                </td>
                <td>
                  <button className="export-btn pdf">PDF Al</button>
                  <button className="export-btn excel">Excel'e Aktar</button>
                </td>
              </tr>
            ))}
          </tbody>
        </table>
      </div>
    </div>
  );
};

export default SalesReportsPage;