// StockCampaignManagementPage.jsx
import React, { useState } from 'react';

const StockCampaignManagementPage = () => {
  const [stock] = useState([
    { id: 1, product: 'ERP Pro Lisans', stock: 45, threshold: 50 },
    { id: 2, product: 'Bulut Depolama 100GB', stock: 23, threshold: 30 },
    { id: 3, product: 'E-Ticaret Entegrasyon', stock: 12, threshold: 20 }
  ]);

  const [campaigns, setCampaigns] = useState([
    { id: 1, name: 'Yazılım Paket İndirimi', status: 'active', discount: 15 },
    { id: 2, name: 'Bulut Depolama Kampanyası', status: 'planned', discount: 20 }
  ]);

  const [newCampaign, setNewCampaign] = useState({
    name: '',
    discount: '',
    startDate: '',
    endDate: ''
  });

  const handleAddCampaign = (e) => {
    e.preventDefault();
    // Kampanya ekleme mantığı
  };

  return (
    <div className="dashboard-page">
      <h2 className="page-title">Stok & Kampanya Yönetimi</h2>
      
      <div className="management-container">
        <div className="stock-section">
          <h3>Stok Durumu</h3>
          <div className="stock-list">
            {stock.map(item => (
              <div key={item.id} className="stock-item">
                <div className="stock-info">
                  <span className="product-name">{item.product}</span>
                  <span className={`stock-quantity ${item.stock < item.threshold ? 'low' : ''}`}>
                    {item.stock} Adet
                  </span>
                </div>
                <div className="progress-bar">
                  <div 
                    className="progress-fill" 
                    style={{ width: `${(item.stock / item.threshold) * 100}%` }}
                  ></div>
                </div>
              </div>
            ))}
          </div>
        </div>

        <div className="campaign-section">
          <h3>Aktif Kampanyalar</h3>
          <div className="campaign-list">
            {campaigns.map(campaign => (
              <div key={campaign.id} className={`campaign-card ${campaign.status}`}>
                <div className="campaign-header">
                  <h4>{campaign.name}</h4>
                  <span className="status-dot"></span>
                </div>
                <div className="campaign-details">
                  <span>İndirim: %{campaign.discount}</span>
                  <span>Durum: {campaign.status === 'active' ? 'Aktif' : 'Planlanan'}</span>
                </div>
              </div>
            ))}
          </div>

          <form onSubmit={handleAddCampaign} className="campaign-form">
            <h4>Yeni Kampanya Ekle</h4>
            <input
              type="text"
              placeholder="Kampanya Adı"
              value={newCampaign.name}
              onChange={(e) => setNewCampaign({...newCampaign, name: e.target.value})}
            />
            <input
              type="number"
              placeholder="İndirim Oranı (%)"
              value={newCampaign.discount}
              onChange={(e) => setNewCampaign({...newCampaign, discount: e.target.value})}
            />
            <div className="date-inputs">
              <input
                type="date"
                value={newCampaign.startDate}
                onChange={(e) => setNewCampaign({...newCampaign, startDate: e.target.value})}
              />
              <input
                type="date"
                value={newCampaign.endDate}
                onChange={(e) => setNewCampaign({...newCampaign, endDate: e.target.value})}
              />
            </div>
            <button type="submit" className="add-button">Kampanya Ekle</button>
          </form>
        </div>
      </div>
    </div>
  );
};

export default StockCampaignManagementPage;