import React from 'react';

const LoginPage = ({ onLogin }) => {
  const handleLogin = (role) => {
    const users = {
      admin: { name: 'Admin User', role: 'admin' },
      distributor: { name: 'Distributor User', role: 'distributor' },
      retailer: { name: 'Retailer User', role: 'retailer' },
      customer: { name: 'Customer User', role: 'customer' },
    };
    onLogin(users[role]);
  };

  return (
    <div style={styles.loginContainer}>
      <div style={styles.loginBox}>
        <h1 style={styles.loginTitle}>Software License Dashboard</h1>
        <div style={styles.buttonContainer}>
          <button
            onClick={() => handleLogin('admin')}
            style={{ ...styles.loginButton, ...styles.admin }}
          >
            Login as Admin
          </button>
          <button
            onClick={() => handleLogin('distributor')}
            style={{ ...styles.loginButton, ...styles.distributor }}
          >
            Login as Distributor
          </button>
          <button
            onClick={() => handleLogin('retailer')}
            style={{ ...styles.loginButton, ...styles.retailer }}
          >
            Login as Retailer
          </button>
          <button
            onClick={() => handleLogin('customer')}
            style={{ ...styles.loginButton, ...styles.customer }}
          >
            Login as Customer
          </button>
        </div>
      </div>
    </div>
  );
};

const styles = {
  loginContainer: {
    minHeight: '100vh',
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'center',
    background: 'linear-gradient(135deg, #f5f7fa 0%, #c3cfe2 100%)',
    padding: '20px',
  },
  loginBox: {
    background: 'rgba(255, 255, 255, 0.95)',
    padding: '2.5rem',
    borderRadius: '15px',
    boxShadow: '0 8px 30px rgba(0, 0, 0, 0.12)',
    width: '100%',
    maxWidth: '400px',
    position: 'relative',
    overflow: 'hidden',
    animation: 'fadeInUp 0.6s ease',
  },
  loginTitle: {
    fontSize: '1.8rem',
    fontWeight: 700,
    color: '#2d3748',
    textAlign: 'center',
    marginBottom: '2rem',
    position: 'relative',
  },
  buttonContainer: {
    display: 'flex',
    flexDirection: 'column',
    gap: '1rem',
  },
  loginButton: {
    width: '100%',
    padding: '0.8rem',
    border: 'none',
    borderRadius: '8px',
    fontSize: '1rem',
    fontWeight: '500',
    cursor: 'pointer',
    transition: 'all 0.3s ease',
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'center',
    gap: '0.5rem',
    position: 'relative',
    overflow: 'hidden',
  },
  loginButtonHover: {
    transform: 'translateY(-2px)',
    boxShadow: '0 4px 6px rgba(0, 0, 0, 0.1)',
  },
  loginButtonActive: {
    transform: 'translateY(0)',
  },
  admin: {
    background: '#4299e1',
    color: 'white',
  },
  distributor: {
    background: '#48bb78',
    color: 'white',
  },
  retailer: {
    background: '#9f7aea',
    color: 'white',
  },
  customer: {
    background: '#ed8936',
    color: 'white',
  },
};

export default LoginPage;
